@@ -30,6 +30,7 @@ import six
 from werkzeug import utils
 from werkzeug import wrappers
 
+from tensorboard import plugin_util
 from tensorboard.backend import http_util
 from tensorboard.plugins import base_plugin
 from tensorboard.util import tb_logging
@@ -88,14 +89,22 @@ class CorePlugin(base_plugin.TBPlugin):
         '/histograms': self._redirect_to_index,
         '/images': self._redirect_to_index,
     }
-    if self._assets_zip_provider:
-      with self._assets_zip_provider() as fp:
-        with zipfile.ZipFile(fp) as zip_:
-          for path in zip_.namelist():
-            gzipped_asset_bytes = _gzip(zip_.read(path))
-            apps['/' + path] = functools.partial(
-                self._serve_asset, path, gzipped_asset_bytes)
-      apps['/'] = apps['/index.html']
+    apps.update(self.get_resource_apps())
+    return apps
+
+  def get_resource_apps(self):
+    apps = {}
+    if not self._assets_zip_provider:
+      return apps
+
+    with self._assets_zip_provider() as fp:
+      with zipfile.ZipFile(fp) as zip_:
+        for path in zip_.namelist():
+          gzipped_asset_bytes = _gzip(zip_.read(path))
+          wsgi_app = functools.partial(
+              self._serve_asset, path, gzipped_asset_bytes)
+          apps['/' + path] = wsgi_app
+    apps['/'] = apps['/index.html']
     return apps
 
   @wrappers.Request.application
@@ -122,7 +131,7 @@ class CorePlugin(base_plugin.TBPlugin):
     * window_title is the title of the TensorBoard web page.
     """
     if self._data_provider:
-      experiment = request.args.get('experiment', '')
+      experiment = plugin_util.experiment_id(request.environ)
       data_location = self._data_provider.data_location(experiment)
     else:
       data_location = self._logdir or self._db_uri
@@ -159,7 +168,7 @@ class CorePlugin(base_plugin.TBPlugin):
     last, and then ties are broken by sorting on the run name.
     """
     if self._data_provider:
-      experiment = request.args.get('experiment', '')
+      experiment = plugin_util.experiment_id(request.environ)
       runs = sorted(
           self._data_provider.list_runs(experiment_id=experiment),
           key=lambda run: (
@@ -235,7 +244,7 @@ class CorePlugin(base_plugin.TBPlugin):
     """
     results = []
     if self._db_connection_provider:
-      exp_id = request.args.get('experiment')
+      exp_id = plugin_util.experiment_id(request.environ)
       runs_dict = collections.OrderedDict()
 
       db = self._db_connection_provider()
@@ -434,9 +443,9 @@ present and --logdir is not specified.\
 An optional, relative prefix to the path, e.g. "/path/to/tensorboard".
 resulting in the new base url being located at
 localhost:6006/path/to/tensorboard under default settings. A leading
-slash is required when specifying the path_prefix, however trailing
-slashes can be omitted. The path_prefix can be leveraged for path based
-routing of an elb when the website base_url is not available e.g.
+slash is required when specifying the path_prefix. A trailing slash is
+optional and has no effect. The path_prefix can be leveraged for path
+based routing of an ELB when the website base_url is not available e.g.
 "example.site.com/path/to/tensorboard/".\
 ''')
 
@@ -489,7 +498,7 @@ reload finishes, and requires --load_interval=0. (default: %(default)s)\
         # Custom str-to-bool converter since regular bool() doesn't work.
         type=lambda v: {'true': True, 'false': False}.get(v.lower(), v),
         choices=[True, False],
-        default=False,
+        default=None,
         help='''\
 [experimental] If true, this enables experimental support for continuously
 polling multiple event files in each run directory for newly appended data
@@ -497,7 +506,7 @@ polling multiple event files in each run directory for newly appended data
 polled as long as their most recently read data is newer than the threshold
 defined by --reload_multifile_inactive_secs, to limit resource usage. Beware
 of running out of memory if the logdir contains many active event files.
-(default: %(default)s)\
+(default: false)\
 ''')
 
     parser.add_argument(
@@ -567,8 +576,10 @@ flag.\
     elif flags.host is not None and flags.bind_all:
       raise FlagsError('Must not specify both --host and --bind_all.')
 
-    if flags.path_prefix.endswith('/'):
-      flags.path_prefix = flags.path_prefix[:-1]
+    flags.path_prefix = flags.path_prefix.rstrip('/')
+    if flags.path_prefix and not flags.path_prefix.startswith('/'):
+      raise FlagsError(
+          'Path prefix must start with slash, but got: %r.' % flags.path_prefix)
 
   def load(self, context):
     """Creates CorePlugin instance."""
