@@ -44,6 +44,8 @@ import sys
 import threading
 import time
 
+from absl import flags as absl_flags
+from absl.flags import argparse_flags
 import absl.logging
 import six
 from six.moves import urllib
@@ -59,13 +61,6 @@ from tensorboard.plugins.core import core_plugin
 from tensorboard.util import argparse_util
 from tensorboard.util import tb_logging
 
-try:
-  from absl import flags as absl_flags
-  from absl.flags import argparse_flags
-except ImportError:
-  # Fall back to argparse with no absl flags integration.
-  absl_flags = None
-  argparse_flags = argparse
 
 logger = tb_logging.get_logger()
 
@@ -127,13 +122,19 @@ class TensorBoard(object):
     """Creates new instance.
 
     Args:
-      plugin: A list of TensorBoard plugins to load, as TBPlugin classes or
+      plugins: A list of TensorBoard plugins to load, as TBPlugin classes or
         TBLoader instances or classes. If not specified, defaults to first-party
         plugins.
       assets_zip_provider: Delegates to TBContext or uses default if None.
       server_class: An optional factory for a `TensorBoardServer` to use
         for serving the TensorBoard WSGI app. If provided, its callable
         signature should match that of `TensorBoardServer.__init__`.
+
+    :type plugins:
+      list[
+        base_plugin.TBLoader | Type[base_plugin.TBLoader] |
+        Type[base_plugin.TBPlugin]
+      ]
     """
     if plugins is None:
       from tensorboard import default
@@ -223,7 +224,7 @@ class TensorBoard(object):
         arguments=argv[1:],
         configure_kwargs=kwargs,
     )
-    if absl_flags and arg0:
+    if arg0:
       # Only expose main module Abseil flags as TensorBoard native flags.
       # This is the same logic Abseil's ArgumentParser uses for determining
       # which Abseil flags to include in the short helpstring.
